@@ -5,13 +5,15 @@
 #include "selectfromlistwindow.h"
 
 BonusDisciplineWindow::BonusDisciplineWindow(QWidget *parent, Book* book, Player* player, int number) :
-    QDialog(parent),
+    DialogWindow(parent),
     ui(new Ui::BonusDisciplineWindow)
 {
     ui->setupUi(this);
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation);
-#endif
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif        
+
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice, true);
     connect(m_RandomPicker, SIGNAL(Random(int)), SLOT(GetRandomSlot(int)));
     connect(ui->pbnOk, SIGNAL(clicked()), SLOT(OkSlot()));
@@ -130,6 +132,15 @@ void BonusDisciplineWindow::ChooseSlot()
                     Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
                     foreach (QString w, m_Elements)
                         wm->Weapons.append(Weapon::GetClass(w));
+                }else if (name == "Psi-surge"){
+                    d->Active = false;
+                    // Add also Mindblast:
+                    if (!m_Player->HasDiscipline("Mindblast")){
+                        Mindblast* m = new Mindblast(m_Player);
+                        m->Active = false;
+                        m->Serie = 0; // To avoid counting it in GetDisciplineCount
+                        m_Player->KaiDisciplines.append(m);
+                    }
                 }
                 m_Player->KaiDisciplines.append(d);
             }
@@ -225,6 +236,15 @@ void BonusDisciplineWindow::OkSlot()
                     Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
                     foreach (QString w, m_Elements)
                         wm->Weapons.append(Weapon::GetClass(w));
+                }else if (d->Name == "Psi-surge"){
+                    d->Active = false;
+                    // Add also Mindblast:
+                    if (!m_Player->HasDiscipline("Mindblast")){
+                        Mindblast* m = new Mindblast(m_Player);
+                        m->Active = false;
+                        m->Serie = 0; // To avoid counting it in GetDisciplineCount
+                        m_Player->KaiDisciplines.append(m);
+                    }
                 }
                 m_Player->KaiDisciplines.append(d);
             }
@@ -240,12 +260,11 @@ void BonusDisciplineWindow::AddWeaponMastery()
     for (int i=Weapon::Dagger; i<=Weapon::Bow; i++)
         weapons.append(Weapon::ClassDescription(i));
 
-    int number = m_Player->GetDisciplineCount() == 0 ? 3 : m_Player->GetDisciplineCount() + 1 - 3;
+    int number = m_Player->GetDisciplineCount() == 0 ? 3 : m_Player->GetDisciplineCount();
     SelectFromListWindow* dlg = new SelectFromListWindow(this, "Select weapons",
                                                          QString("Select %1 weapons for the Weaponmastery discipline").arg(number),
                                                          weapons, number);
-    dlg->exec();
-
+    while (dlg->exec() != QDialog::Accepted	){}
     m_Elements = dlg->GetSelected();
 }
 
@@ -264,7 +283,7 @@ void BonusDisciplineWindow::CheckWeaponMasteryBonus()
         SelectFromListWindow* dlg = new SelectFromListWindow(this, "Select weapons",
                                                              "Select 1 weapon for the Weaponmastery discipline",
                                                              weapons, 1);
-        dlg->exec();
+        while (dlg->exec() != QDialog::Accepted	){}
         foreach (QString w, dlg->GetSelected())
             wm->Weapons.append(Weapon::GetClass(w));
     }
