@@ -214,6 +214,12 @@ BookWindow::BookWindow(QWidget *parent) :
     foreach (QPushButton* pbn, m_ChoiceButtons)
         connect(pbn, SIGNAL(clicked()), SLOT(ChoiceSlot()));
 
+    ui->pbnEnd->setVisible(false);
+    ui->pbnFight->setVisible(false);
+    ui->pbnItems->setVisible(false);
+    ui->pbnRandom->setVisible(false);
+    ui->pbnShop->setVisible(false);
+    SetVisibleChoiceButtons(0);
 
     connect(ui->pbnShop, SIGNAL(clicked()), SLOT(ShopSlot()));
     connect(ui->pbnInventory, SIGNAL(clicked()), SLOT(StatusSlot()));
@@ -255,7 +261,7 @@ void BookWindow::Init()
 
     QScriptValue objectValue = m_Engine.newQObject(m_Player);
     m_Engine.globalObject().setProperty("Player", objectValue);
-    ShowSection(m_Section != NULL ? m_Section->Number : 0);
+    //ShowSection(m_Section != NULL ? m_Section->Number : 0);
 }
 
 BookWindow::~BookWindow()
@@ -375,7 +381,15 @@ void BookWindow::ShowSectionChoices(int section)
             ui->pbnFight->setEnabled(true);
             ui->pbnItems->setVisible(false);
             ui->pbnRandom->setVisible(false);
-            SetVisibleChoiceButtons(0);
+            SetVisibleChoiceButtons(0);            
+            foreach (Choice* c, m_Section->Choices){
+                if (c->ShowWithEnemies){
+                    QPushButton* pbn = m_ChoiceButtons.at(m_Section->Choices.indexOf(c));
+                    pbn->setVisible(true);
+                    pbn->setEnabled(c->Enabled);
+                }
+            }
+
             ui->pbnShop->setVisible(false);
 
             if (m_Section->Choices.count() > 0)
@@ -483,16 +497,42 @@ void BookWindow::ExitSection()
     if (!m_Section->ExitScript.isEmpty()){
         ExecuteScript("ExitScript", m_Section->ExitScript);
     }
-    m_Player->TemporaryCombatSkillDelta = 0;
 
-    if (m_Book->GetSerie() == Book::Kai && m_Player->HasDiscipline("Healing") && !m_Fought){
-        if (m_Player->Endurance + 1 <= m_Player->GetBaseEndurance())
-            m_Player->Endurance += 1;
-    }else if (m_Book->GetSerie() == Book::Magnakai && m_Player->HasDiscipline("Curing") && !m_Fought){
-        if (m_Player->Endurance + 1 <= m_Player->GetBaseEndurance())
-            m_Player->Endurance += 1;
+    EndTempCombatSkillEffect();
+
+    if (m_Player->HasDiscipline("Healing") && !m_Fought)
+        m_Player->SetEndurance(m_Player->GetEndurance() + 1);
+
+    if(m_Player->HasDiscipline("Curing") && !m_Fought)
+        m_Player->SetEndurance(m_Player->GetEndurance() + 1);
+
+}
+
+void BookWindow::EndTempCombatSkillEffect()
+{
+    if (m_Player->TemporaryCombatSkillDelta > 0){
+        m_Player->TemporaryCombatSkillDelta = 0;
+        // Run the "end effect" script if present:
+        QString name = m_Player->GetTemporaryCombatSkillItem();
+        if (!name.isEmpty()){
+            QScriptValue f = m_Functions.property(QString("endeffect_%1").arg(name.replace("'", "").replace(" ", "")));
+            if (f.isValid()){
+                QScriptValue objectValue = m_Engine.newQObject(this);
+                m_Engine.globalObject().setProperty("Window", objectValue);
+                f.call();
+            }
+            if (m_Engine.hasUncaughtException()){
+                QStringList backTrace = m_Engine.uncaughtExceptionBacktrace();
+                QMessageBox msgBox(this);
+                msgBox.setWindowTitle(QString("Error in %1").arg(name));
+
+                msgBox.setIcon(QMessageBox::Warning);
+                msgBox.setText(QString("%1\n\nBacktrace:\n%2").arg(m_Engine.uncaughtException().toString()).arg(backTrace.join("\n")));
+                msgBox.exec();
+            }
+        }
+        m_Player->SetTemporaryCombatSkillItem("");
     }
-
 }
 
 void BookWindow::DoChoice(int number)
@@ -553,6 +593,8 @@ void BookWindow::FightSlot()
 #endif
     ShowSection(m_Section->Number);
     m_Fought = true;
+
+    EndTempCombatSkillEffect();
 }
 
 void BookWindow::GetRandomSlot()
@@ -783,7 +825,12 @@ void BookWindow::show()
 {
     QMainWindow::show();
     if (m_Section)
-        ShowSection(m_Section->Number);
+        QTimer::singleShot(250, this, SLOT(ShowSectionSlot()));
+}
+
+void BookWindow::ShowSectionSlot()
+{
+    ShowSection(m_Section->Number);
 }
 
 QString BookWindow::GetTempSaveFilename()
@@ -878,9 +925,6 @@ bool BookWindow::Load(QString filename)
     QVariant var = settings.value("player");
     if (var.isValid()){
         m_Player = new Player(var.value<Player>());
-#ifndef QT_NO_DEBUG
-        m_Player->Dump();
-#endif
     }
 
     int index = settings.beginReadArray("items");
@@ -889,6 +933,8 @@ bool BookWindow::Load(QString filename)
         var = settings.value("item");
         if (var.isValid()){
             Item* i = new Item(var.value<Item>());
+            if (i->GetUUID().isEmpty())
+                i->SetUUID(QUuid::createUuid().toString());
             // For compatibility with previously saved positions, check if the item has
             // the CanBeEquipped property
             if ((i->GetIsArmor() || i->GetIsWeapon()) && !i->HasProperty("CanBeEquipped"))
@@ -897,28 +943,68 @@ bool BookWindow::Load(QString filename)
         }else{
             var = settings.value("weapon");
             if (var.isValid()){
-                Weapon* w = new Weapon(var.value<Weapon>());                
+                Weapon* w = new Weapon(var.value<Weapon>());
+                if (w->GetUUID().isEmpty())
+                    w->SetUUID(QUuid::createUuid().toString());
                 // For compatibility with previously saved positions, check if the weapon has
                 // the CanBeEquipped property
                 if (!w->HasProperty("CanBeEquipped"))
                     w->SetCanBeEquipped(true);
+
+                // Fix weapon class:
+                if (w->Classes().count() == 0 || w->Classes().contains(Weapon::None)){
+                    if (!QString::compare(w->GetName(), "Dagger", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Dagger);
+                    else if (!QString::compare(w->GetName(), "Spear", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Spear);
+                    else if (!QString::compare(w->GetName(), "Mace", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Mace);
+                    else if (!QString::compare(w->GetName(), "Warhammer", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::WarHammer);
+                    else if (!QString::compare(w->GetName(), "Axe", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Axe);
+                    else if (!QString::compare(w->GetName(), "Sword", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Sword);
+                    else if (!QString::compare(w->GetName(), "Quarterstaff", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Quarterstaff);
+                    else if (!QString::compare(w->GetName(), "Broadsword", Qt::CaseInsensitive))
+                        w->Classes().append(Weapon::Broadsword);
+                }
+
+                // Fix Sommerswerd (in book 2 the CombatskillDelta was wrong):
+                if (w->GetName() == "Sommerswerd" && w->GetCombatskillDelta() == 10){
+                    w->Classes().clear();
+                    w->AddClass(Weapon::Sword);
+                    w->AddClass(Weapon::Broadsword);
+                    w->AddClass(Weapon::ShortSword);
+                    w->SetCombatskillDelta(8);
+                }
+
                 m_Player->Items.append(w);
             }
         }
     }
     settings.endArray();
 
+#ifndef QT_NO_DEBUG
+        m_Player->Dump();
+#endif
+
     index = settings.beginReadArray("hiddenitems");
     for (int i=0; i<index; i++){
         settings.setArrayIndex(i);
         var = settings.value("item");
         if (var.isValid()){
             Item* i = new Item(var.value<Item>());
+            if (i->GetUUID().isEmpty())
+                i->SetUUID(QUuid::createUuid().toString());
             m_Player->HiddenItems.append(i);
         }else{
             var = settings.value("weapon");
             if (var.isValid()){
                 Weapon* w = new Weapon(var.value<Weapon>());
+                if (w->GetUUID().isEmpty())
+                    w->SetUUID(QUuid::createUuid().toString());
                 m_Player->HiddenItems.append(w);
             }
         }
@@ -979,6 +1065,80 @@ bool BookWindow::Load(QString filename)
     }
     settings.endArray();
 
+    // Fix for discipline bug in book 6 (the Kai disciplines were removed):
+    if (m_Book->GetSerie() == Book::Magnakai){
+        if(!m_Player->HasDiscipline("Camouflage")){
+            Camouflage* d = new Camouflage(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Hunting")){
+            Hunting* d = new Hunting(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Sixth Sense")){
+            SixthSense* d = new SixthSense(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Tracking")){
+            Tracking* d = new Tracking(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Healing")){
+            Healing* d = new Healing(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Weaponskill")){
+            Weaponskill* d = new Weaponskill(m_Player);
+            d->Weapon = Weapon::Sword; // Default to sword
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Mindshield")){
+            Mindshield* d = new Mindshield(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Mindblast")){
+            Mindblast* d = new Mindblast(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Animal Kinship")){
+            AnimalKinship* d = new AnimalKinship(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+        if(!m_Player->HasDiscipline("Mind Over Matter")){
+            MindOverMatter* d = new MindOverMatter(m_Player);
+            d->Serie = 0; // To avoid counting it in GetDisciplineCount
+            m_Player->KaiDisciplines.append(d);
+        }
+    }
+    // Fix for discipline bug in version 0.1.15:
+    if (m_Player->HasDiscipline("Psi-surge") && !m_Player->HasDiscipline("Mindblast")){
+        Mindblast* m = new Mindblast(m_Player);
+        m->Serie = 0; // To avoid counting it in GetDisciplineCount
+        m->Active = false;
+        m_Player->KaiDisciplines.append(m);
+    }else if (m_Player->HasDiscipline("Psi-surge") && m_Player->HasDiscipline("Mindblast")){
+        KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
+        d->Serie = 0;
+    }else if (!m_Player->HasDiscipline("Psi-surge") && m_Player->HasDiscipline("Mindblast")){
+        m_Player->RemoveDiscipline("Mindblast");
+    }
+
+    // Change Psi-surge when reached Archmaster (9 Disciplines)
+    if (m_Player->HasDiscipline("Psi-surge") && m_Player->GetDisciplineCount() >= 9){
+        KaiDiscipline* d = m_Player->GetDiscipline("Psi-surge");
+        d->CombatSkillDelta = 6;
+        d->HelpText = "+6 COMBAT SKILL points but -1 ENDURANCE points per round";
+    }
+
     m_Loaded = true;
     return true;
 }
@@ -990,6 +1150,14 @@ QString BookWindow::GetBookSaveFilename(int number)
     return filename;
 }
 
+QString BookWindow::ChooseMeal(QString title)
+{
+    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseMeal);
+    dlg->setWindowTitle(title);
+    dlg->exec();
+    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+}
+
 QString BookWindow::ChooseWeapon(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseWeapon);
@@ -1221,6 +1389,20 @@ void BookWindow::EnableChoiceButton(int choice)
     m_ChoiceButtons.at(choice)->setEnabled(true);
 }
 
+void BookWindow::DisableChoiceButtons()
+{
+    for (int i=0; i<m_Section->Choices.count(); i++){
+        m_ChoiceButtons.at(i)->setEnabled(false);
+    }
+}
+
+void BookWindow::EnableChoiceButtons()
+{
+    for (int i=0; i<m_Section->Choices.count(); i++){
+        m_ChoiceButtons.at(i)->setEnabled(m_Section->Choices.at(i)->Enabled);
+    }
+}
+
 void BookWindow::ShopSlot()
 {
 #ifndef Q_WS_MAEMO_5
