@@ -12,6 +12,10 @@ namespace Ui {
     class BookWindow;
 }
 
+//!  The main window
+/*!
+
+*/
 class BookWindow : public QMainWindow
 {
     Q_OBJECT
@@ -59,11 +63,14 @@ private:
     bool Load(QString filename="");
     QString GetTempSaveFilename();
 
+    void EndTempCombatSkillEffect();
+
 protected:
     void resizeEvent(QResizeEvent *event);
 
 private slots:
     void LoadFinishedSlot(bool);
+    void ShowSectionSlot();
     void GoSlot();
 
     void ChoiceSlot();
@@ -83,40 +90,74 @@ private slots:
     void ScrollToTopSlot();
 
 public slots:
+    /** Print a message on the window */
     void Print(QString);
+    /** Display a message box */
     void MessageBox(QString title, QString message);
+    /** Returns the name of a meal choosen by the player */
+    QString ChooseMeal(QString title);
+    /** Returns the name of a weapon choosen by the player */
     QString ChooseWeapon(QString title);
+    /** Returns the name of a backpack item choosen by the player */
     QString ChooseItem(QString title);
+    /** Returns the name of a backpack item (except meals) choosen by the player */
     QString ChooseItemExceptMeals(QString title);
+    /** Returns the name of a special item choosen by the player */
     QString ChooseSpecialItem(QString title);
+    /** Ask the player to add a bonus discipline */
     void AddBonusDiscipline();
+    /** Ask the player to add bonus disciplines */
     void AddBonusDisciplines(int number);
+    /** Loads the next book */
     bool LoadNextBook();
     void show();
 
+    /** Clears the pick items list */
     void ClearPickItems();
-    // Add gold crowns to the pick item window.
-    // If goldCrowns is < 0 then the number will be picked using a random number
+    /** Adds gold crowns to the pick item window.
+    If goldCrowns is < 0 then the number will be picked using a random number */
     void AddPickGoldCrowns(int goldCrowns);
+    /** Adds random number gold crowns to the pick item window with the given bonus. */
     void AddPickRandomGoldCrowns(int bonus);
+    /** Adds a item (or special item) to the pick item window. */
     Item* AddPickItem(QString name, bool special);
+    /** Adds a meal to the pick item window. */
     Item* AddMealPickItem(QString name);
+    /** Adds a weapon to the pick item window. */
     Weapon* AddWeaponPickItem(QString name, QString className);
+    /** Adds a healing item to the pick item window. */
     Item* AddHealingPickItem(QString name, int enduranceDelta);
+    /** Let the player pick items from the pick item window. */
     int PickItems(int max);
+    /** Returns a number of Gold Crowns selected by the player */
     int SelectGoldCrowns(int min);
+    /** Returns a random number */
     int GetRandomNumber();
+    /** Returns a random number using the given bonus */
     int GetRandomNumberWithBonus(int bonus);
+    /** Disables the given choice button */
     void DisableChoiceButton(int);
+    /** Enables the given choice button */
     void EnableChoiceButton(int);
+    /** Disables all the choice buttons */
+    void DisableChoiceButtons();
+    /** Enables all the choice buttons (of enabled choices) */
+    void EnableChoiceButtons();
+    /** Executes the given choice */
     void DoChoice(int number);
+    /** Disables the "Fight" button */
     void DisableFightButton();
+    /** Enables the "Fight" button */
     void EnableFightButton();
+    /** Returns a number selected by the player in the given range */
+    int InputNumber(QString title, int min, int max);
 
+    /** Play the "Cartwheel" game (book 2) */
     void PlayCartwheel();
+    /** Play the "Portholes" game (book 2) */
     void PlayPortholes();
+    /** Play the bet game (book 6) */
     int PlayBetGame();
-    int InputNumber(QString, int, int);
 };
 
 #endif // BOOKWINDOW_H
