@@ -35,7 +35,6 @@ class Choice : public QObject
 
 public:
     explicit Choice(QObject *parent = 0);
-    //Choice(const Choice& choice);
 
     bool Enabled;
     int Target;
@@ -43,6 +42,7 @@ public:
     bool Random;
     int MinValue;
     int MaxValue;
+    bool ShowWithEnemies;
 
     QString Script;
 
@@ -57,12 +57,14 @@ public slots:
     void Accept() {m_Abort = false; }
 };
 
+class Book;
 class Section : public QObject
 {
     Q_OBJECT
 public:
     explicit Section(QObject *parent = 0);
 
+    Book* GetBook() { return (Book*)parent(); }
     int Number;
     QString Text;
     QList<Choice*> Choices;
@@ -94,6 +96,8 @@ public slots:
     void SetMustEat(int value) { MustEat = value; }
     // Remove one item from the section, returns true if the item has been removed
     bool RemoveItem(QString name);
+    Item* AddItem(QString name, bool special);
+    void CopyItemsToSection(int section);
 };
 
 
@@ -127,6 +131,7 @@ public:
     bool Save(QString filename);
     QString GetVersion();
     int GetSerie();
+    Section* GetSection(int section);
 
 private:
     QString AddGenericFunctions(QString functions);
