@@ -3,12 +3,13 @@
 #include "commonstatic.h"
 
 PickItemsWindow::PickItemsWindow(QWidget *parent, Player* player, int serie, int goldCrowns, QList<Item*>* items, int max) :
-    QDialog(parent),
+    DialogWindow(parent),
     ui(new Ui::PickItemsWindow)
 {
     ui->setupUi(this);
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation);
+    setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
     m_Serie = serie;
@@ -125,7 +126,9 @@ void PickItemsWindow::ShowData(bool full)
         break;
     }
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
-    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
+    ui->lblArrows->setText(QString("%1/%2")
+                           .arg(m_Player->GetArrows())
+                           .arg(m_Player->GetMaxArrows()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
