@@ -5,13 +5,14 @@
 #include <QCheckBox>
 #include <QMessageBox>
 #include "core/player.h"
+#include "controls/dialogwindow.h"
 #include "randomnumberpicker.h"
 
 namespace Ui {
     class PickItemsWindow;
 }
 
-class PickItemsWindow : public QDialog
+class PickItemsWindow : public DialogWindow
 {
     Q_OBJECT
 
