@@ -8,10 +8,11 @@
 #include "core/books.h"
 
 PlayerCreationWindow::PlayerCreationWindow(QWidget *parent) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::PlayerCreationWindow)
 {
     ui->setupUi(this);
+    SetCanClose(true);
 #ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     CommonStatic::CenterWindow(this);
@@ -37,7 +38,6 @@ PlayerCreationWindow::PlayerCreationWindow(QWidget *parent) :
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice);
     connect(m_RandomPicker, SIGNAL(Random(int)), SLOT(RandomSlot(int)));
 
-    m_Loop = NULL;
     m_Player = new Player();
     m_Player->AddItem("Map of Sommerlund", true);
     m_Player->AddMeal("Meal");
@@ -89,20 +89,6 @@ PlayerCreationWindow::~PlayerCreationWindow()
     delete ui;
 }
 
-void PlayerCreationWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
-void PlayerCreationWindow::closeEvent(QCloseEvent*)
-{
-    if (m_Loop)
-        m_Loop->quit();
-    QMainWindow::close();
-}
-
 Player* PlayerCreationWindow::GetPlayer()
 {
     if (m_SkillDone && m_EnduranceDone && m_CrownsDone && m_ItemDone && CheckDisciplines())
