@@ -4,10 +4,11 @@
 #include "commonstatic.h"
 
 ShopWindow::ShopWindow(QWidget *parent, Player* player, Section* section) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::ShopWindow)
 {
     ui->setupUi(this);
+    SetCanClose(true);
 #ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     CommonStatic::CenterWindow(this);
@@ -19,7 +20,6 @@ ShopWindow::ShopWindow(QWidget *parent, Player* player, Section* section) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-    m_Loop = NULL;
     m_Player = player;
     m_Section = section;
 
@@ -33,20 +33,6 @@ ShopWindow::~ShopWindow()
     delete ui;
 }
 
-void ShopWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
-void ShopWindow::closeEvent(QCloseEvent* event)
-{
-    if (m_Loop)
-        m_Loop->quit();
-    event->accept();
-}
-
 void ShopWindow::ShowData()
 {
     int row = 0;
@@ -116,7 +102,9 @@ void ShopWindow::ShowData()
     }
 
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
-    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
+    ui->lblArrows->setText(QString("%1/%2")
+                           .arg(m_Player->GetArrows())
+                           .arg(m_Player->GetMaxArrows()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
