@@ -7,12 +7,16 @@
 #endif
 #include "commonstatic.h"
 #include "ruleswindow.h"
+#include "combatskillwindow.h"
+#include "noteswindow.h"
+#include "controls/qdisabledcheckbox.h"
 
 StatusWindow::StatusWindow(QWidget *parent, Player* player, Section* section, QScriptEngine* engine, QScriptValue* functions) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::StatusWindow)
 {
     ui->setupUi(this);
+    SetCanClose(true);
 #ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     CommonStatic::CenterWindow(this);
@@ -38,11 +42,16 @@ StatusWindow::StatusWindow(QWidget *parent, Player* player, Section* section, QS
     ui->lblEquippedArmor->setPalette(secondaryPalette);
 #endif
 
+    ui->statusLayout->setAlignment(ui->chkQuiver, Qt::AlignRight);
+    ui->lblCombatSkillD->setText("<a href=\"#\">Combat Skill:</a>");
+    connect(ui->lblCombatSkillD, SIGNAL(linkActivated(QString)), this, SLOT(CombatSkillLinkSlot(QString)));
+
     connect(ui->pbnDropWeapon1, SIGNAL(clicked()), this, SLOT(DropWeapon1Slot()));
     connect(ui->pbnDropWeapon2, SIGNAL(clicked()), this, SLOT(DropWeapon2Slot()));
     connect(ui->pbnEquip1, SIGNAL(clicked()), this, SLOT(EquipWeapon1Slot()));
     connect(ui->pbnEquip2, SIGNAL(clicked()), this, SLOT(EquipWeapon2Slot()));
     connect(ui->pbnPickGoldCrowns, SIGNAL(clicked()), this, SLOT(TakeGoldCrownsSlot()));
+    connect(ui->pbnEditNotes, SIGNAL(clicked()), this, SLOT(EditNotesSlot()));
 
     m_Engine = engine;
     m_Functions = functions;
@@ -58,22 +67,10 @@ StatusWindow::~StatusWindow()
     delete ui;
 }
 
-void StatusWindow::closeEvent(QCloseEvent*)
-{
-    if (m_Loop)
-        m_Loop->quit();
-    QMainWindow::close();
-}
-
-void StatusWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
 void StatusWindow::ShowData()
 {
+    ui->lblNotes->setText(m_Player->GetNotes());
+
     switch (m_Serie){
     case Book::Kai:
         ui->lblDisciplines->setText("Kai Disciplines:");
@@ -144,7 +141,10 @@ void StatusWindow::ShowData()
     ui->lblCrowns->setText(QString("%1/50").arg(m_Player->GoldCrowns));
     ui->lblMeals->setText(QString::number(m_Player->MealsCount()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
-    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
+    ui->chkQuiver->setEnabled(false);
+    ui->lblArrows->setText(QString("%1/%2")
+                           .arg(m_Player->GetArrows())
+                           .arg(m_Player->GetMaxArrows()));
 
     QList<Weapon*> weapons = m_Player->Weapons();
     ui->pbnDropWeapon1->setEnabled(false);
@@ -277,11 +277,10 @@ void StatusWindow::ShowData()
                 lbl->setText(Weapon::ClassDescription(w));
                 ui->layWeaponChecklist->addWidget(lbl, wrow, 0);
 
-                QCheckBox* chk = new QCheckBox(this);
-                chk->setLayoutDirection(Qt::RightToLeft);
-                chk->setEnabled(false);
+                QDisabledCheckBox* chk = new QDisabledCheckBox(this);
                 chk->setChecked(wm->Weapons.contains(w));
-                ui->layWeaponChecklist->addWidget(chk, wrow, 1);
+                chk->setEnabled(false);
+                ui->layWeaponChecklist->addWidget(chk, wrow, 1, Qt::AlignRight);
 
                 wrow++;
             }
@@ -426,6 +425,42 @@ void StatusWindow::ShowData()
     }
 }
 
+bool StatusWindow::EquipArmor(Armor* armor)
+{
+    if (armor->GetIsEquipped()){
+        armor->Unequip();
+    }else{
+        if (armor->GetClass() == Armor::Shield && !m_Player->GetCanUseShield()){
+            QMessageBox msgBox(this);
+            msgBox.setText("You cannot equip a shield now.");
+            msgBox.exec();
+            return false;
+        }
+
+        // Unequip the armor of the same class if present
+        QList<Armor*> equipped = m_Player->GetEquippedArmors();
+        foreach (Armor* a, equipped){
+            if (a->GetArmorClass() == armor->GetClass())
+                a->Unequip();
+        }
+
+        // Check free hands (only for shield
+        if (armor->GetClass() == Armor::Shield){
+            if (m_Player->GetFreeHands() >= 1){
+                armor->Equip();
+            }else{
+                QMessageBox msgBox(this);
+                msgBox.setText("You cannot equip a shield now.");
+                msgBox.exec();
+                return false;
+            }
+        }else
+            armor->Equip();
+    }
+    m_Player->CheckEndurance();
+    return true;
+}
+
 bool StatusWindow::EquipWeapon(Weapon* weapon)
 {
     if (weapon->GetIsEquipped()){
@@ -435,7 +470,14 @@ bool StatusWindow::EquipWeapon(Weapon* weapon)
         Weapon* equipped = m_Player->GetEquippedWeapon();
         if (equipped != NULL)
             equipped->Unequip();
-        weapon->Equip();
+        if (m_Player->GetFreeHands() >= weapon->GetHands())
+            weapon->Equip();
+        else{
+            QMessageBox msgBox(this);
+            msgBox.setText("You cannot equip this weapon now.");
+            msgBox.exec();
+            return false;
+        }
     }
     return true;
 }
@@ -497,14 +539,9 @@ void StatusWindow::EquipItemSlot()
             if (EquipWeapon(w))
                 ShowData();
         }else if (i->GetIsArmor()){
-            if (m_Player->GetFreeHands() < i->GetHands()){
-                QMessageBox msgBox(this);
-                msgBox.setText("You cannot equip this item now.");
-                msgBox.exec();
-            }else{
-                i->Equip();
+            Armor* a = (Armor*)i;
+            if (EquipArmor(a))
                 ShowData();
-            }
         }
     }
 }
@@ -659,3 +696,17 @@ void StatusWindow::DiscipleLinkSlot(QString link)
     dlg->show();
     dlg->ScrollToAnchor(link);
 }
+
+void StatusWindow::CombatSkillLinkSlot(QString)
+{
+    CombatSkillWindow* dlg = new CombatSkillWindow(this, m_Player, NULL);
+    dlg->exec();
+}
+
+void StatusWindow::EditNotesSlot()
+{
+    NotesWindow* dlg = new NotesWindow(this, m_Player);
+    dlg->exec();
+
+    ui->lblNotes->setText(m_Player->GetNotes());
+}
